binutil

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reader

type Reader struct {
	Data []byte
	Pos  int
	Err  error
}

Reader is a sequential binary reader with error accumulation. Once an error is set, all subsequent reads return zero values.

func (*Reader) ReadBool

func (r *Reader) ReadBool() bool

func (*Reader) ReadBytes

func (r *Reader) ReadBytes(n int) []byte

func (*Reader) ReadFloat64

func (r *Reader) ReadFloat64() float64

func (*Reader) ReadString

func (r *Reader) ReadString() string

func (*Reader) ReadU8

func (r *Reader) ReadU8() uint8

func (*Reader) ReadU16

func (r *Reader) ReadU16() uint16

func (*Reader) ReadU32

func (r *Reader) ReadU32() uint32

type Writer

type Writer struct {
	Buf []byte
	Err error
}

Writer is an append-only binary writer with error accumulation. Once an error is set, all subsequent writes are no-ops.

func (*Writer) WriteBool

func (w *Writer) WriteBool(v bool)

func (*Writer) WriteBytes

func (w *Writer) WriteBytes(b []byte)

func (*Writer) WriteFloat64

func (w *Writer) WriteFloat64(v float64)

func (*Writer) WriteString

func (w *Writer) WriteString(s string)

func (*Writer) WriteU8

func (w *Writer) WriteU8(v uint8)

func (*Writer) WriteU16

func (w *Writer) WriteU16(v uint16)

func (*Writer) WriteU32

func (w *Writer) WriteU32(v uint32)

Jump to