Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reader ¶
Reader is a sequential binary reader with error accumulation. Once an error is set, all subsequent reads return zero values.
func (*Reader) ReadFloat64 ¶
func (*Reader) ReadString ¶
type Writer ¶
Writer is an append-only binary writer with error accumulation. Once an error is set, all subsequent writes are no-ops.
func (*Writer) WriteBytes ¶
func (*Writer) WriteFloat64 ¶
func (*Writer) WriteString ¶
Click to show internal directories.
Click to hide internal directories.